@@ -1,3 +1,4 @@
+#include "config.h"
 #include "saphire.h"
 #include <string.h>
 #include <strings.h>
@@ -13,8 +14,10 @@
 #include <oniguruma.h>
 #include <readline/readline.h>
 #include <readline/history.h>
-
-#include "config.h"
+#include <limits.h>
+#include <signal.h>
+#include <sys/wait.h>
+#include <sys/stat.h>
 
 #if defined(HAVE_CURSES_H)
 #include <curses.h>
@@ -24,44 +27,7 @@
 #include <ncurses/ncurses.h>
 #endif
 
-#include <limits.h>
-#include <sys/stat.h>
-
-#ifdef __LINUX__
-
-/*
-#define __USE_POSIX
-#define __USE_XOPEN_EXTENDED
-#define __USE_POSIX199309
-#define __USE_UNIX98
-*/
-#include <signal.h>
-#include <sys/wait.h>
-
-#else
-
-#include <signal.h>
-#include <sys/stat.h>
-
-#endif
-
-#if defined(__DARWIN__)
-#include <sys/syslimits.h>
-#endif
-
-#ifdef __FREEBSD__
-#include <limits.h>
-#endif
-
 #include "saphire_extra.h"
-/*
-#if !defined(__FREEBSD__)
-void srandom(unsigned int seed);
-#endif
-int setenv(const char *name, const char *value, int overwrite);
-int unsetenv(const char *name);
-int strcasecmp(const char *s1, const char *s2);
-*/
 
 /// from readline.c ///
 void readline_init();
@@ -83,7 +49,7 @@ static void atexit_fun()
 //////////////////////////////////////////////////////////////////////
 static void usage()
 {
-    printf("usage sash or saphire [-c command] [ -s -w -e ] [ -Lu -Lm -Lw ] [--version ] [ script file]\n\n");
+    printf("usage saphiresh or saphire [-c command] [ -s -w -e ] [ -Lu -Lm -Lw ] [--version ] [ script file]\n\n");
     printf("-c : eval a command on saphire\n");
     printf("-rs : use run time a source run time script\n");
     printf("-ro : use run time a compiled run time script(default)\n");
@@ -351,7 +317,7 @@ int main(int argc, char* argv[])
         saphire_init(kATOptC, FALSE, runtime_script, FALSE);
         sWFd* pipeout = sWFd_new(STDOUT_FILENO);
         sRFd* pipein = sRFd_new(STDIN_FILENO);
-        int rcode = saphire_shell(send_cmd + 1, "saphire -a", pipeout, pipein, STDERR_FILENO);
+        int rcode = saphire_shell(send_cmd + 1, "saphire -c", pipeout, pipein, STDERR_FILENO);
         saphire_sweep();
 
         sWFd_flash(pipeout);
@@ -376,7 +342,7 @@ int main(int argc, char* argv[])
     setenv("SAPHIRE_INTERACTIVE", "1", 1);
 
 #if !defined(ENABLE_READLINE)
-    fprintf(stderr, "if you use saphire as interactive shell, use sash command instead\n");
+    fprintf(stderr, "if you use saphire as interactive shell, use saphiresh command instead\n");
     for(i=0; i<vector_size(argv2); i++) {
         string_delete(vector_item(argv2, i));
     }
