@@ -6,9 +6,6 @@
 ////////////////////////////////////////////////////////////
 extern volatile BOOL gSigUser;
 
-extern hash_obj* gMatchRestart;
-    // matchǻȤѿ
-
 /// ޥɤбʸ
 enum eCommandKind { 
     kSubshell, kMSleep, kTrue, kFalse, kTest,
@@ -17,8 +14,8 @@ enum eCommandKind {
     kJobs, kRehash, kKanjiCode, kLineField, kVar, kGlobal,
     kCalc, kExport, kPrint,  kPuts, kLoad, 
     kWhile, kBreak, kExit, kIf, kSplit, kX, kJoin, kSelect, kLines, kRows,
-    kAryNew, kAryAdd, kAryErase, kAryClear, 
-    kHashNew, kHashAdd, kHashErase, kHashClear, kMatch, kScan, kErase, kSub,
+    kAryNew, kAryAdd, kAryErase, 
+    kHashNew, kHashAdd, kHashErase, kMatch, kScan, kErase, kSub,
     kRead, 
     kCd, 
     kAdd, kDel, kSelector, kMax, kMin,
@@ -63,9 +60,6 @@ enum eCommandKind {
     kCommand 
 };
 
-void err_msg(char* msg, char* sname, int line);
-    // 顼å
-
 extern string_obj* gAncestalMemoryPipeIn;
     // ȥåץ٥ޥѤΥѥ
 extern string_obj* gAncestalMemoryPipeOut;
@@ -90,8 +84,6 @@ extern BOOL gJobControl;
     // ֤Υȥ򤹤뤫ɤ
 extern vector_obj* gJobs;
     //  sJob*
-extern list_obj* gSigChldRecieved;  
-    // SIGCHLDäPID,STATUSΥꥹ
 
 extern char* gMagicNumber;
     // ֥ȥեΥޥåʥС
@@ -146,13 +138,6 @@ extern hash_obj* gFWriteBuffers;
     // ϥեǥץֹʸ
     // ƤϽ񤭹ե
 
-#if defined(__LINUX__) || defined(__DARWIN__) || defined(__FREEBSD__)
-extern int gMsgId;
-    // å塼
-    // fork˿ƥץȻҥץ̿˻Ȥ
-    // (ץ롼פѤä)
-#endif
-
 extern hash_obj* gInnerCommands;
     // Ͽޥ
     // saphireȤ߹ץꥱ
@@ -241,6 +226,7 @@ typedef struct
 } sWhile;
 
 sWhile* sWhile_new(MANAGED sStatments* joukensiki, MANAGED sStatments* contents);
+sWhile* sWhile_new2(sWhile* while_);
 
 void sWhile_delete(sWhile* self);
 void sWhile_save(sWhile* self, int fd);
@@ -253,6 +239,7 @@ typedef struct
 } sTry;
 
 sTry* sTry_new(MANAGED sStatments* loops, MANAGED sStatments* loops2);
+sTry* sTry_new2(sTry* try_);
 void sTry_view(sTry* self);
 void sTry_delete(sTry* self);
 void sTry_save(sTry* self, int fd);
@@ -264,6 +251,7 @@ typedef struct
 } sSubshell;
 
 sSubshell* sSubshell_new(MANAGED sStatments* contents);
+sSubshell* sSubshell_new2(sSubshell* subshell);
 
 void sSubshell_delete(sSubshell* self);
 void sSubshell_save(sSubshell* self, int fd);
@@ -277,6 +265,7 @@ typedef struct
 } sIf;
 
 sIf* sIf_new(MANAGED vector_obj* joukensiki_list, MANAGED vector_obj* contents_list);
+sIf* sIf_new2(sIf* if_);
 
 void sIf_delete(sIf* self);
 void sIf_save(sIf* self, int fd);
@@ -297,6 +286,7 @@ typedef struct {
 } sRedirect; // ¹Ի˻Ȥ ֥ȥե¸
 
 sRedirect* sRedirect_new(enum eRedirect type, int fd, char* fname);
+sRedirect* sRedirect_new2(sRedirect* redirect);
 void sRedirect_save(sRedirect* self, int fd);
 sRedirect* sRedirect_load(int fd);
 void sRedirect_delete(sRedirect* self);
@@ -318,17 +308,14 @@ typedef struct {
 } sVar;
 
 sVar* sVar_new(MANAGED string_obj* name,  MANAGED string_obj* index, MANAGED string_obj* index2, MANAGED string_obj* delimiter);
+sVar* sVar_new2(sVar* var);
 void sVar_delete(sVar* self);
 
 sVar* sVar_load(int fd);
 void sVar_save(sVar* self, int fd);
 
-typedef struct {
-    sStatments* mStatments;
-    vector_obj* mArgs;
-} sBlock;
-
 sBlock* sBlock_new(sStatments* statments, vector_obj* args);
+sBlock* sBlock_new2(sBlock* block);
 void sBlock_delete(sBlock* self);
 void sBlock_save(sBlock* self, int fd);
 sBlock* sBlock_load(int fd);
@@ -349,6 +336,7 @@ typedef struct
 } sArg; // mArgs
 
 sArg* sArg_new(int kind, void* body);
+sArg* sArg_new2(sArg* arg);
 void sArg_delete(sArg* arg);
 
 void sArg_save(sArg* self, int fd);
@@ -421,6 +409,8 @@ sStatment* sStatment_new();
 
 #endif
 
+sStatment* sStatment_new2(sStatment* statment);
+
 void sStatment_delete(sStatment* self);
 void sStatment_save(sStatment* self, int fd);
 sStatment* sStatment_load(int fd);
@@ -450,6 +440,7 @@ typedef struct {
 } sFunction;
 
 sFunction* sFunction_new(char* name, MANAGED sStatments* statments, char* arg_name);
+sFunction* sFunction_new2(sFunction* func);
   
 void sFunction_delete(sFunction* self);
 void sFunction_save(sFunction* self, int fd);
